@@ -113,7 +113,8 @@ class ModelUtils:
         # self.types = mlflow.types
         self.xgboost = mlflow.xgboost
 
-    def set_tracking_uri(url):
+    def set_tracking_uri(self, url):
         tracking_uri = "https://mlflow.sidetrek.com"
         from mlflow import set_tracking_uri
         set_tracking_uri(tracking_uri)
+        print("Tracking uri can't be changed")
